==> haskell-email-validate-2.3.2.10-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.10
id: email-validate-2.3.2.10-Ki6cO6DGhLHAJRGjduy2j7
key: email-validate-2.3.2.10-Ki6cO6DGhLHAJRGjduy2j7
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: 684c0f7c74dc7f8f0172bebf81fd86f0
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.3/site-local/email-validate-2.3.2.10
library-dirs: /usr/lib/ghc-8.6.3/site-local/email-validate-2.3.2.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/email-validate-2.3.2.10
hs-libraries: HSemail-validate-2.3.2.10-Ki6cO6DGhLHAJRGjduy2j7
depends:
    attoparsec-0.13.2.2-5xLw3754VYU1jRp4MrlfX3 base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.10-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.10
id: email-validate-2.3.2.10-2njUPOZZQJhDZ5cQxK1SH0
key: email-validate-2.3.2.10-2njUPOZZQJhDZ5cQxK1SH0
license: BSD-3-Clause
maintainer: George Pollard <porges@porg.es>
author: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
abi: 807cd4685c43de0ad1aa9685a3aa640e
exposed: True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
import-dirs: /usr/lib/ghc-8.6.4/site-local/email-validate-2.3.2.10
library-dirs: /usr/lib/ghc-8.6.4/site-local/email-validate-2.3.2.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/email-validate-2.3.2.10
hs-libraries: HSemail-validate-2.3.2.10-2njUPOZZQJhDZ5cQxK1SH0
depends:
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    bytestring-0.10.8.2 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
